@@ -29,6 +29,7 @@ Contact: yuvraaj@gmail.com
 #endif
 
 class CQmlViewer;
+class QmlStubBase;
 class QmlMainWindow : public IMainWindow
 {
     Q_OBJECT
@@ -39,11 +40,12 @@ public:
     virtual void init();
     void log(QDateTime dt, int level, const QString &strLog);
 
+public slots:
+    void messageReceived(const QString &msg);
+
 protected slots:
     void onViewerStatusChanged(bool ready);
 
-    void messageReceived(const QString &msg);
-
     void uiShowStatusMessage(const QString &msg, quint64 millisec);
     void uiClearStatusMessage();
     void uiShowMessageBox(const QString &msg);
@@ -115,6 +117,8 @@ protected:
     void uiEnableInboxUpdateFrequency(bool enable);
     void uiSetInboxUpdateFrequency(quint32 mins);
 
+    QString correctedPhotoUrlPath(QString path);
+
 protected:
     CQmlViewer *m_view;
 
@@ -142,6 +146,9 @@ protected:
     QObject *edContactsUpdateFreq;
     QObject *edInboxUpdateFreq;
 
+    friend class QmlStubBase;
+    QmlStubBase *m_qmlStub;
+
     void    *loginCtx;
 
     bool     m_inboxDetailsShown;
